Files
TheRock/rocm-systems/projects/hip-tests/catch/unit/executionContext/hipExecutionCtxStreamCreate.cc
T
derek.holloway 7502bf64a4
CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
Flatten subprojects into a single base monorepo
2026-09-02 16:34:47 -07:00

137 lines
4.0 KiB
C++

/*
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
*
* SPDX-License-Identifier: MIT
*/
/**
* @addtogroup hipExecutionCtx hipExecutionCtx
* @{
* @ingroup ExecutionContextTest
* `hipExecutionCtxStreamCreate` - stream create, negative, and detach tests
*/
#include <hip_test_common.hh>
#include "hip_executionctx_common.hh"
/**
* Test Description
* ------------------------
* - Creates a green context and its stream using SM resources
* Test requirements
* ------------------------
* - HIP_VERSION >= 7.2
*/
HIP_TEST_CASE(Unit_hipExecutionCtxStreamCreate_Sanity) {
HIP_CHECK(hipSetDevice(0));
hipDevResourceDesc_t desc{};
hipError_t ret = GetSmResourceDesc(&desc);
REQUIRE(ret == hipSuccess);
hipExecutionCtx_t green_ctx = nullptr;
HIP_CHECK(hipGreenCtxCreate(&green_ctx, desc, 0, 0));
REQUIRE(green_ctx != nullptr);
hipStream_t stream = nullptr;
HIP_CHECK(hipExecutionCtxStreamCreate(&stream, green_ctx, hipStreamNonBlocking, 0x0));
REQUIRE(stream != nullptr);
HIP_CHECK(hipStreamSynchronize(stream));
HIP_CHECK(hipStreamDestroy(stream));
HIP_CHECK(hipExecutionCtxDestroy(green_ctx));
}
/**
* Test Description
* ------------------------
* - Negative parameter validation for hipExecutionCtxStreamCreate and hipStreamGetExecutionCtx
* Test requirements
* ------------------------
* - HIP_VERSION >= 7.2
*/
HIP_TEST_CASE(Unit_hipExecutionCtxStreamCreate_Negative) {
HIP_CHECK(hipSetDevice(0));
hipDevResourceDesc_t desc{};
hipError_t ret = GetSmResourceDesc(&desc);
REQUIRE(ret == hipSuccess);
hipExecutionCtx_t green_ctx = nullptr;
HIP_CHECK(hipGreenCtxCreate(&green_ctx, desc, 0, 0));
REQUIRE(green_ctx != nullptr);
hipStream_t valid_stream = nullptr;
HIP_CHECK(hipExecutionCtxStreamCreate(&valid_stream, green_ctx, hipStreamNonBlocking, 0x0));
REQUIRE(valid_stream != nullptr);
hipStream_t stream = nullptr;
SECTION("stream create with null stream pointer") {
HIP_CHECK_ERROR(hipExecutionCtxStreamCreate(nullptr, green_ctx, hipStreamNonBlocking, 0x0), hipErrorInvalidValue);
}
SECTION("stream create with invalid green context") {
hipExecutionCtx_t invalid_green_ctx = nullptr;
HIP_CHECK_ERROR(hipExecutionCtxStreamCreate(&stream, invalid_green_ctx, hipStreamNonBlocking, 0x0),
hipErrorInvalidValue);
}
SECTION("stream create with invalid flags") {
constexpr unsigned int kInvalidFlags = 0xFFFFFFFF;
HIP_CHECK_ERROR(hipExecutionCtxStreamCreate(&stream, green_ctx, kInvalidFlags, 0x0),
hipErrorInvalidValue);
}
HIP_CHECK(hipStreamDestroy(valid_stream));
HIP_CHECK(hipExecutionCtxDestroy(green_ctx));
}
/**
* Test Description
* ------------------------
* - Verifies that after hipExecutionCtxDestroy, stream-accepting APIs
* return hipErrorStreamDetached while hipStreamDestroy still succeeds.
* Test requirements
* ------------------------
* - HIP_VERSION >= 7.2
*/
HIP_TEST_CASE(Unit_hipExecutionCtxStreamDestroy_Negative) {
HIP_CHECK(hipSetDevice(0));
hipDevResourceDesc_t desc{};
hipError_t ret = GetSmResourceDesc(&desc);
REQUIRE(ret == hipSuccess);
hipExecutionCtx_t green_ctx = nullptr;
HIP_CHECK(hipGreenCtxCreate(&green_ctx, desc, 0, 0));
REQUIRE(green_ctx != nullptr);
hipStream_t stream = nullptr;
HIP_CHECK(hipExecutionCtxStreamCreate(&stream, green_ctx, hipStreamNonBlocking, 0x0));
REQUIRE(stream != nullptr);
HIP_CHECK(hipStreamSynchronize(stream));
HIP_CHECK(hipExecutionCtxDestroy(green_ctx));
SECTION("hipStreamSynchronize returns hipErrorStreamDetached") {
HIP_CHECK_ERROR(hipStreamSynchronize(stream), hipErrorStreamDetached);
}
SECTION("hipStreamQuery returns hipErrorStreamDetached") {
HIP_CHECK_ERROR(hipStreamQuery(stream), hipErrorStreamDetached);
}
SECTION("hipStreamDestroy succeeds on detached stream") {
HIP_CHECK(hipStreamDestroy(stream));
stream = nullptr;
}
if (stream != nullptr) {
HIP_CHECK(hipStreamDestroy(stream));
}
}
/**
* End doxygen group hipExecutionCtx.
* @}
*/